<?php

declare(strict_types=1);

namespace Drupal\Tests\openid_connect\Functional;

use Drupal\Core\Url;
use Drupal\Tests\BrowserTestBase;

/**
 * Test the login form openid_connect alterations.
 *
 * @group openid_connect
 */
class LogoutUserTest extends BrowserTestBase {

  use OpenIdClientTestTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'openid_connect',
    'user',
    'block',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->createTestClient('test', 'Test OIDC Client');
    $this->placeBlock('system_menu_block:account');
  }

  /**
   * Confirm CSRF token is required to log out.
   */
  public function testCsrfOnLogout(): void {
    $logoutUrl = Url::fromRoute('user.logout');
    $account = $this->createUser();
    $this->drupalLogin($account);

    // Test missing csrf token does not log the user out.
    $this->drupalGet($logoutUrl);
    $this->assertTrue($this->drupalUserIsLoggedIn($account));
    $this->assertSession()->statusCodeEquals(403);

    // Test invalid csrf token does not log the user out.
    $this->drupalGet($logoutUrl, ['query' => ['token' => '123']]);
    $this->assertTrue($this->drupalUserIsLoggedIn($account));
    $this->assertSession()->statusCodeEquals(403);

    // Test with valid logout link.
    $this->drupalGet('user');
    $this->getSession()->getPage()->clickLink('Log out');
    $this->assertFalse($this->drupalUserIsLoggedIn($account));
  }

}
